package com 
{
	import org.flixel.*;
	
	/**
	 * ...
	 * @author Lulzy & Villermen
	 */
	public class MapLoader extends FlxGroup
	{		
		public var currentMap:uint = 1;
		
		public var maps:Vector.<String> = new Vector.<String>();
		public var objects:Vector.<String> = new Vector.<String>();
		public var decos:Vector.<String> = new Vector.<String>();
		
		/**
		 * Previous map segment
		 */
		public var previousSegment:MapSegment;
		
		/**
		 * Current map segment
		 */
		public var currentSegment:MapSegment;
		
		/**
		 * Next map segment
		 */
		public var nextSegment:MapSegment;
		
		/**
		 * More tutorial flags
		 */
		public var tutorialLoaded:uint = 0;
		
		/**
		 * Textfields for tutorial messages
		 */
		public var txtGroup:FlxGroup;
		
		public function MapLoader() 
		{
			maps[0] = Assets.tutorial_maps[0];
			maps[1] = Assets.tutorial_maps[1];
			objects[0] = Assets.tutorial_objects[0];
			objects[1] = Assets.tutorial_objects[1];
			decos[0] = Assets.tutorial_decos[0];
			decos[1] = Assets.tutorial_decos[1];
			
			if (Main.tutorial)
			{
				maps[2] = Assets.tutorial_maps[2];
				objects[2] = Assets.tutorial_objects[2];
				decos[2] = Assets.tutorial_decos[2];
			}
			else
			{
				var segment:uint = uint(Math.floor(Math.random() * Assets.maps.length));
				maps[2] = Assets.maps[segment];
				objects[2] = Assets.objects[segment];
				decos[2] = Assets.decos[segment];
			}
			
			previousSegment = new MapSegment(maps[0], objects[0], decos[0], -800);
			add(previousSegment);
			
			currentSegment = new MapSegment(maps[1], objects[1], decos[1]);
			add(currentSegment);
			
			nextSegment = new MapSegment(maps[2], objects[2], decos[2], 800);
			add(nextSegment);
			
			if (Main.tutorial)
			{
				txtGroup = new FlxGroup();
				add(txtGroup);
				loadTutorial();
			}
		}
		
		override public function update():void
		{
			if (Main.tutorial && tutorialLoaded < 3)
			{
				loadTutorial()
			}
			
			if (PlayState.player.x >= 800)
			{
				currentMap++;
				
				if (currentMap + 1 == maps.length) // TODO: NOT THIS
				{
					var loadedMaps:Vector.<uint> = new Vector.<uint>();
					do
					{
						var segment:uint = uint(Math.floor((Math.random() * Assets.maps.length)));
						if (loadedMaps.indexOf(segment) == -1)
						{
							maps[currentMap + 1 + loadedMaps.length] = Assets.maps[segment];
							objects[currentMap + 1 + loadedMaps.length] = Assets.objects[segment];
							decos[currentMap + 1 + loadedMaps.length] = Assets.decos[segment];
							loadedMaps.push(segment);
						}
					} while (loadedMaps.length < Assets.maps.length)
					
					
				}
				previousSegment.loadMapData(maps[currentMap - 1]);
				previousSegment._offSetX = -800;
				previousSegment.loadObjectData(objects[currentMap - 1], false);
				previousSegment.loadDecoData(decos[currentMap - 1]);
				
				currentSegment.loadMapData(maps[currentMap]);
				currentSegment.loadObjectData(objects[currentMap]);
				currentSegment.loadDecoData(decos[currentMap]);
				
				nextSegment.loadMapData(maps[currentMap + 1]);
				nextSegment._offSetX = 800;
				nextSegment.loadObjectData(objects[currentMap + 1]);
				nextSegment.loadDecoData(decos[currentMap + 1]);
				
				PlayState.player.x -= 800;
			}
			
			if (PlayState.player.x < 0)
			{
				currentMap--;
				
				previousSegment.loadMapData(maps[currentMap - 1]);
				previousSegment._offSetX = -800;
				previousSegment.loadObjectData(objects[currentMap - 1], false);
				previousSegment.loadDecoData(decos[currentMap - 1]);
				
				currentSegment.loadMapData(maps[currentMap]);
				currentSegment.loadObjectData(objects[currentMap], false);
				currentSegment.loadDecoData(decos[currentMap]);
				
				nextSegment.loadMapData(maps[currentMap + 1]);
				nextSegment._offSetX = 800;
				nextSegment.loadObjectData(objects[currentMap + 1], false);
				nextSegment.loadDecoData(decos[currentMap + 1]);
				
				PlayState.player.x += 800;
			}
			
			super.update();
		}
		
		public function loadTutorial():void
		{
			if (currentMap == 1 && tutorialLoaded == 0)
			{
				var txt:FlxText = new FlxText(100, 120, 300, "You are stuck in a facility filled with deadly radiation\nBetter find something to protect yourself!")
				txt.size = 16;
				txtGroup.add(txt);
				
				txt = new FlxText(100, 220, 300, "Use A/D to move, W to jump");
				txt.size = 16;
				txtGroup.add(txt);
				
				txt = new FlxText(540, 440, 300, "SPROING");
				txt.size = 16;
				txtGroup.add(txt);
				
				txt = new FlxText(500, 240, 300, "Girders are one-way");
				txt.size = 8;
				txtGroup.add(txt);
				
				txt = new FlxText(460, 120, 400, "Collect lead to survive the radiation!");
				txt.size = 16;
				txt.alignment = "center";
				txtGroup.add(txt);
				
				tutorialLoaded++;
			}
			else if (currentMap == 2 && tutorialLoaded == 1)
			{
				txtGroup.clear();
				
				txt = new FlxText(200, 200, 250, "You can grab pipes from below, S to drop down");
				txt.size = 12;
				txtGroup.add(txt);
				
				txt = new FlxText(45, 64, 300, "<- Alive time left");
				txt.size = 16;
				txt.scrollFactor = new FlxPoint();
				txtGroup.add(txt);
				
				txt = new FlxText(400, 64, 300, "Score ->");
				txt.scrollFactor = new FlxPoint();
				txt.alignment = "right";
				txt.size = 16;
				txtGroup.add(txt);
				
				txt = new FlxText(260, 380, 180, "Acid is not pleasant");
				txt.size = 16;
				txtGroup.add(txt);
				
				txt = new FlxText(580, 360, 220, "Radiation will start now, survive!");
				txt.size = 16;
				txtGroup.add(txt);
				
				tutorialLoaded++;
			}
			else if (currentMap == 3 && tutorialLoaded == 2)
			{
				txtGroup.clear();
				
				tutorialLoaded++;
				
				PlayState.player.timeLeft = 10;
				
				Main.tutorial = false;
			}
		}
		
	}

}